# remirepo spec file for php-pecl-geospatial
#
# Copyright (c) 2015-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-pecl-geospatial}

%global gh_commit   d3f3ab0a836f10eacb7e117c06f12ea57e1e8649
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    php-geospatial
%global gh_project  geospatial
#global gh_date     20150908
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name   geospatial
%global ini_name    40-%{pecl_name}.ini
%global sources     %{gh_project}-%{gh_commit}
%global _configure  ../%{sources}/configure

%bcond_without  tests

Summary:        PHP Extension to handle common geospatial functions
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        0.3.2
%if 0%{?gh_date:1}
Release:        0.11.%{gh_date}git%{gh_short}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%else
Release:        3%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%endif

License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{pecl_name}-%{version}-%{gh_short}.tar.gz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-json

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

# Package have be renamed
Obsoletes:      %{?scl_prefix}php-%{pecl_name}               < %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
The extension currently has implementations of the Haversine and
Vincenty's formulas for calculating distances, an initial bearing calculation
function, a Helmert transformation function to transfer between different
supported datums, conversions between polar and Cartesian coordinates,
conversions between Degree/Minute/Seconds and decimal degrees, a method to
simplify linear geometries, as well as a method to calculate intermediate
points on a LineString.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
mv %{sources}/package.xml .

%{?_licensedir:sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml}

cd %{sources}
# Check version as upstream often forget to update this
extver=$(sed -n '/#define PHP_GEOSPATIAL_VERSION/{s/.* "//;s/".*$//;p}' php_geospatial.h)
if test "x${extver}" != "x%{version}%{?prever}%{?gh_date:-dev}"; then
   : Error: Upstream version is ${extver}, expecting %{version}%{?prever}%{?gh_date:-dev}.
   exit 1
fi
cd ..

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} module
extension = %{pecl_name}.so
EOF

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif


%build
%{?dtsenable}

peclconf() {
%configure \
    --with-php-config=$1
}

cd %{sources}
%{__phpize}

cd ../NTS
peclconf %{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
peclconf %{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Install the ZTS stuff
%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do [ -f NTS/$i ] &&  install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

OPT="-n"
if [ -f %{php_extdir}/json.so ]; then
  OPT="$OPT -d extension=json.so"
fi

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="$OPT -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%else
: Upstream test suite disabled
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
: Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="$OPT -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%else
: Upstream test suite disabled
%endif
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%{!?_licensedir:%doc %{pecl_docdir}/%{pecl_name}}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%{php_ztsextdir}/%{pecl_name}.so
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%endif


%changelog
* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 0.3.2-3
- build out of sources tree

* Thu Sep  1 2022 Remi Collet <remi@remirepo.net> - 0.3.2-2
- rebuild for PHP 8.2.0RC1

* Thu Aug 11 2022 Remi Collet <remi@remirepo.net> - 0.3.2-1
- update to 0.3.2

* Thu Jan 28 2021 Remi Collet <remi@remirepo.net> - 0.3.1-1
- update to 0.3.1
- raise dependency on PHP 7.0

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 0.2.1-3
- add patch for PHP 8 from
  https://github.com/php-geospatial/geospatial/pull/27

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.2.1-2
- rebuild for 7.4.0RC1

* Tue Jan  8 2019 Remi Collet <remi@remirepo.net> - 0.2.1-1
- update to 0.2.1

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.2.0-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.2.0-2
- rebuld for 7.3.0alpha4 new ABI

* Fri Dec 29 2017 Remi Collet <remi@remirepo.net> - 0.2.0-1
- Update to 0.2.0 (beta)

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.1.0-6
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 0.1.0-5
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 0.1.0-4
- rebuild for PHP 7.1 new API version

* Mon Jun  6 2016 Remi Collet <remi@fedoraproject.org> - 0.1.0-3
- fix license installation on EL-6

* Sat Mar  5 2016 Remi Collet <remi@fedoraproject.org> - 0.1.0-2
- adapt for F24

* Sat Dec  5 2015 Remi Collet <remi@fedoraproject.org> - 0.1.0-1
- initial package, version 0.1.0 (experimental)

